@@ -39,7 +39,10 @@
  *           mmclennan@lucent.com
  *           http://www.tcltk.com/itcl
  *
- *     RCS:  $Id$
+ *       modified for Stubs 5/20/1999 by 
+ *           David Gravereaux <davygrvy@bigfoot.com>
+ *
+ *     RCS:  $Id: itcl.h,v 1.7 1999/05/25 17:28:58 redman Exp $
  * ========================================================================
  *           Copyright (c) 1993-1998  Lucent Technologies, Inc.
  * ------------------------------------------------------------------------
@@ -51,15 +54,21 @@
 
 #include "tcl.h"
 
+#undef TCL_STORAGE_CLASS
 #ifdef BUILD_itcl
-# undef TCL_STORAGE_CLASS
 # define TCL_STORAGE_CLASS DLLEXPORT
+#else
+# ifdef USE_ITCL_STUBS
+#  define TCL_STORAGE_CLASS
+# else
+#  define TCL_STORAGE_CLASS DLLIMPORT
+# endif
 #endif
 
-#define ITCL_VERSION "3.0"
-#define ITCL_PATCH_LEVEL "3.0.1"
+#define ITCL_VERSION "3.1"
+#define ITCL_PATCH_LEVEL "3.1.0"
 #define ITCL_MAJOR_VERSION 3
-#define ITCL_MINOR_VERSION 0
+#define ITCL_MINOR_VERSION 1
 #define ITCL_RELEASE_LEVEL 0
 
 /* 
@@ -128,55 +137,16 @@ typedef struct Itcl_InterpState_ *Itcl_InterpState;
 
 
 /*
- *  Exported functions
+ * Include the public function declarations that are accessible via
+ * the stubs table.
  */
-EXTERN int Itcl_Init _ANSI_ARGS_((Tcl_Interp *interp));
-EXTERN int Itcl_SafeInit _ANSI_ARGS_((Tcl_Interp *interp));
 
-EXTERN int Itcl_RegisterC _ANSI_ARGS_((Tcl_Interp *interp,
-    char *name, Tcl_CmdProc *proc, ClientData clientData,
-    Tcl_CmdDeleteProc *deleteProc));
-EXTERN int Itcl_RegisterObjC _ANSI_ARGS_((Tcl_Interp *interp,
-    char *name, Tcl_ObjCmdProc *proc, ClientData clientData,
-    Tcl_CmdDeleteProc *deleteProc));
-EXTERN int Itcl_FindC _ANSI_ARGS_((Tcl_Interp *interp, char *name,
-    Tcl_CmdProc **argProcPtr, Tcl_ObjCmdProc **objProcPtr,
-    ClientData *cDataPtr));
+#include "itclDecls.h"
 
-EXTERN void Itcl_InitStack _ANSI_ARGS_((Itcl_Stack *stack));
-EXTERN void Itcl_DeleteStack _ANSI_ARGS_((Itcl_Stack *stack));
-EXTERN void Itcl_PushStack _ANSI_ARGS_((ClientData cdata,
-    Itcl_Stack *stack));
-EXTERN ClientData Itcl_PopStack _ANSI_ARGS_((Itcl_Stack *stack));
-EXTERN ClientData Itcl_PeekStack _ANSI_ARGS_((Itcl_Stack *stack));
-EXTERN ClientData Itcl_GetStackValue _ANSI_ARGS_((Itcl_Stack *stack,
-    int pos));
+/*
+ * Public functions that are not accessible via the stubs table.
+ */
 
-EXTERN void Itcl_InitList _ANSI_ARGS_((Itcl_List *listPtr));
-EXTERN void Itcl_DeleteList _ANSI_ARGS_((Itcl_List *listPtr));
-EXTERN Itcl_ListElem* Itcl_CreateListElem _ANSI_ARGS_((Itcl_List *listPtr));
-EXTERN Itcl_ListElem* Itcl_DeleteListElem _ANSI_ARGS_((Itcl_ListElem *elemPtr));
-EXTERN Itcl_ListElem* Itcl_InsertList _ANSI_ARGS_((Itcl_List *listPtr,
-    ClientData val));
-EXTERN Itcl_ListElem* Itcl_InsertListElem _ANSI_ARGS_((Itcl_ListElem *pos,
-    ClientData val));
-EXTERN Itcl_ListElem* Itcl_AppendList _ANSI_ARGS_((Itcl_List *listPtr,
-    ClientData val));
-EXTERN Itcl_ListElem* Itcl_AppendListElem _ANSI_ARGS_((Itcl_ListElem *pos,
-    ClientData val));
-EXTERN void Itcl_SetListValue _ANSI_ARGS_((Itcl_ListElem *elemPtr,
-    ClientData val));
-
-EXTERN void Itcl_EventuallyFree _ANSI_ARGS_((ClientData cdata,
-    Tcl_FreeProc *fproc));
-EXTERN void Itcl_PreserveData _ANSI_ARGS_((ClientData cdata));
-EXTERN void Itcl_ReleaseData _ANSI_ARGS_((ClientData cdata));
-
-EXTERN Itcl_InterpState Itcl_SaveInterpState _ANSI_ARGS_((Tcl_Interp* interp,
-    int status));
-EXTERN int Itcl_RestoreInterpState _ANSI_ARGS_((Tcl_Interp* interp,
-    Itcl_InterpState state));
-EXTERN void Itcl_DiscardInterpState _ANSI_ARGS_((Itcl_InterpState state));
 
 #endif /* RESOURCE INCLUDED */
 
