@@ -6,7 +6,7 @@
 # ----------------------------------------------------------------------
 #  AUTHOR: Mark L. Ulferts               EMAIL: mulferts@spd.dsccc.com
 #
-#  @(#) $Id$
+#  @(#) $Id: iwidgets.tcl,v 1.2 1999/01/25 21:43:43 stanton Exp $
 # ----------------------------------------------------------------------
 #                Copyright (c) 1995  Mark L. Ulferts
 # ======================================================================
@@ -27,3 +27,9 @@ namespace eval ::iwidgets {
 
 lappend auto_path [file join $iwidgets::library scripts]
 package provide Iwidgets $iwidgets::version
+
+# For now we need to import all of the itcl functions into the global
+# namespace. This should be removed once iwidgets are upgraded to use the
+# itcl:: names directly.
+
+namespace import -force itcl::*
